==> cordova-sqlite-react-1.1.8.tgz: package/@types/commonType.ts <==
import { SQLitePlugin } from './SQLitePlugin';


export interface returnCommonPropsPromise {
  status: boolean;
  msg: string;
}

// export interface returnGetDataSqliteT extends Partial<Pick<returnCommonPropsPromise, 'msg'>>, Omit<returnCommonPropsPromise, 'msg'>{
export interface returnGetDataSqliteT extends returnCommonPropsPromise{
  values:[] | {}[];
}

export interface SelectWhere{
  where?:object;
  sql?: string;
}


export interface DeleteWhere extends Omit<SelectWhere, 'sql'>{
  whereKey?: {[key:string]: string[] | undefined};
  ignoreWhere?: {[key:string]: string[] | undefined};
  condition?: 'AND' | 'OR';
  stringWhere?:string | undefined;
}

export interface UpdateWhere extends Omit<DeleteWhere, 'whereKey' | 'ignoreWhere'>{ }

export interface setDataSqliteOptions {
  isCreateDate?: boolean | undefined;
  rewriteTable?: boolean | undefined;
}


export type commonFunctionSqliteT = (connect:SQLitePlugin, nameTable:string) => Promise<returnCommonPropsPromise> 
export type getDataSqliteT = (connect:SQLitePlugin, nameTable:string, {where, sql}:SelectWhere) => Promise<returnGetDataSqliteT> 
export type setDataSqliteT = (connect:SQLitePlugin, nameTable:string, payload: object, options?:setDataSqliteOptions) => Promise<returnCommonPropsPromise> 
export type updateDataSqliteT = (connect:SQLitePlugin, nameTable:string, payload: object, {where, condition, stringWhere}: UpdateWhere) => Promise<returnCommonPropsPromise> 
export type remoteDataSqliteT = (connect:SQLitePlugin, nameTable:string, param:DeleteWhere) => Promise<returnCommonPropsPromise> 

/*#############----------<{ Class Sqlite }>-----------########## */
export type commonMethodSqliteT = (nameTable:string) => Promise<returnCommonPropsPromise> 
export type getDataT = (nameTable:string, {where, sql}:SelectWhere) => Promise<returnGetDataSqliteT> 
export type setDataT = (nameTable:string, payload: object, options?:setDataSqliteOptions) => Promise<returnCommonPropsPromise> 
export type updateDataT = (nameTable:string, payload: object, {where, condition, stringWhere}: UpdateWhere) => Promise<returnCommonPropsPromise> 
export type remoteDataT = (nameTable:string, param:DeleteWhere) => Promise<returnCommonPropsPromise> 


/*#############----------<{ Class SLStore }>-----------########## */

// export type commonMethodSqliteT = (nameTable:string) => Promise<returnCommonPropsPromise> 
export type getItemT = (key:string) => Promise<returnGetDataSqliteT> 
export type setItemT = (key:string, value: any, options?:setDataSqliteOptions) => Promise<returnCommonPropsPromise> 
// export type updateDataT = (nameTable:string, payload: object, {where, condition, stringWhere}: UpdateWhere) => Promise<returnCommonPropsPromise> 
export type remoteItemT = (keys?:string[], ignoreKey?:string[]) => Promise<returnCommonPropsPromise>

==> cordova-sqlite-react-1.1.10.tgz: package/@types/commonType.ts <==
import { SQLitePlugin } from './SQLitePlugin';


export interface returnCommonPropsPromise {
  status: boolean;
  msg: string;
}

// export interface returnGetDataSqliteT extends Partial<Pick<returnCommonPropsPromise, 'msg'>>, Omit<returnCommonPropsPromise, 'msg'>{
export interface returnGetDataSqliteT extends returnCommonPropsPromise{
  values:[] | {}[];
}
export interface returnGetDataSLStoreT extends returnCommonPropsPromise{
  data: {}
}

export interface SelectWhere{
  sql?: string;
}



export interface Params {
  where?:object;
  whereKey?: {[key:string]: string[] | undefined};
  ignoreWhere?: {[key:string]: string[] | undefined};
  condition?: 'AND' | 'OR';
  stringWhere?:string | undefined;
}

export interface UpdateWhere extends Omit<Params, 'whereKey' | 'ignoreWhere'>{ }

export interface setDataSqliteOptions {
  isCreateDate?: boolean | undefined;
  rewriteTable?: boolean | undefined;
}


export type commonFunctionSqliteT = (connect:SQLitePlugin, nameTable?:string) => Promise<returnCommonPropsPromise> 
export type getDataSqliteT = (connect:SQLitePlugin, nameTable:string, params:Params) => Promise<returnGetDataSqliteT> 
export type setDataSqliteT = (connect:SQLitePlugin, nameTable:string, payload: object, options?:setDataSqliteOptions) => Promise<returnCommonPropsPromise> 
export type updateDataSqliteT = (connect:SQLitePlugin, nameTable:string, payload: object, {where, condition, stringWhere}: UpdateWhere) => Promise<returnCommonPropsPromise> 
export type remoteDataSqliteT = (connect:SQLitePlugin, nameTable:string, params:Params) => Promise<returnCommonPropsPromise> 

/*#############----------<{ Class Sqlite }>-----------########## */
export type commonMethodSqliteT = (nameTable?:string) => Promise<returnCommonPropsPromise> 
export type getDataT = (nameTable:string, params:Params) => Promise<returnGetDataSqliteT> 
export type setDataT = (nameTable:string, payload: object, options?:setDataSqliteOptions) => Promise<returnCommonPropsPromise> 
export type updateDataT = (nameTable:string, payload: object, {where, condition, stringWhere}: UpdateWhere) => Promise<returnCommonPropsPromise> 
export type remoteDataT = (nameTable:string, params:Params) => Promise<returnCommonPropsPromise> 


/*#############----------<{ Class SLStore }>-----------########## */
interface getItemsI {
  ignoreKeys: string[]
}
// export type commonMethodSqliteT = (nameTable:string) => Promise<returnCommonPropsPromise> 
export type getItemT = (key:string) => Promise<returnGetDataSLStoreT> 
export type getItemsT = (options?:getItemsI) => Promise<returnGetDataSLStoreT> 

export type setItemT = (key:string, value: any, options?:setDataSqliteOptions) => Promise<returnCommonPropsPromise> 
// export type updateDataT = (nameTable:string, payload: object, {where, condition, stringWhere}: UpdateWhere) => Promise<returnCommonPropsPromise> 
export type remoteItemT = ({keys, ignoreKey}:{keys?:string[], ignoreKey?:string[]}) => Promise<returnCommonPropsPromise>
